ChangeLog
=========


1.0.3 (2015-04-10)
------------------

* Raise exception when trying to render non-CIDR-like port ranges with a CIDR
  notation.


1.0.2 (2015-04-07)
------------------

* Update all Online Labs references to Scaleway.


1.0.1 (2015-03-26)
------------------

* Check code coverage thanks to coveralls.


1.0.0 (2014-12-11)
------------------

* Split out port range helpers into its own stand-alone package.
* First public release.


0.1.0 (2014-02-17)
------------------

* First internal release.


0.0.0 (2014-02-11)
------------------

* First commit.
